#
# spec file for package avidemux
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define         ffmpeg_version 0.9.4

Name:           avidemux
Summary:        Video processing tool
Version:        2.5.6
Release:        9010.1
Url:            http://fixounet.free.fr/avidemux/
Source0:        avidemux_%{version}.tar.gz
Source1:        %{name}.png
Source2:        %{name}-gtk.desktop
Source3:        %{name}-qt4.desktop
Source4:        ffmpeg-%{ffmpeg_version}.tar.bz2
Source5:        libavcodec_libavcodec.v.patch
Patch0:         avidemux-cpu_armel.patch
Patch1:         fix-internal-plugins-load.patch
Patch2:         avidemux-cpp.patch
Patch3:         avidemux-stdlib.patch
License:        GPL-2.0
Group:          Productivity/Multimedia/Video/Editors and Convertors

%ifarch armv6l || armv6hl
BuildRequires:  Mesa-libEGL1
BuildRequires:  Mesa-libEGL-devel
BuildRequires:  Mesa-libGLESv1_CM1
BuildRequires:  Mesa-libGLESv1_CM-devel
BuildRequires:  Mesa-libGLESv2-2
BuildRequires:  Mesa-libGLESv2-devel
%endif

# Base RPM
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  gettext-runtime
BuildRequires:  gtk2-devel
BuildRequires:  libqt4-devel
BuildRequires:  libxml2-devel
BuildRequires:  libxslt-devel
BuildRequires:  pkg-config
BuildRequires:  update-desktop-files
BuildRequires:  yasm
BuildRequires:  dos2unix
BuildRequires:  SDL-devel

# Codecs
BuildRequires:  alsa-devel
BuildRequires:  arts-devel
BuildRequires:  libesd-devel
BuildRequires:  libfaac-devel
BuildRequires:  libfaad2-devel
BuildRequires:  libdca-devel
BuildRequires:  libjack-devel
BuildRequires:  libmp3lame-devel
BuildRequires:  libopencore-amr-devel
BuildRequires:  libpulse-devel
BuildRequires:  libsamplerate-devel
BuildRequires:  libsndfile-devel
BuildRequires:  libx264-devel
BuildRequires:  libxvidcore-devel
BuildRequires:  libvpx-devel

BuildRoot:      %{_tmppath}/buildroot-%{name}-%{version}

%description
Avidemux is a free video editor designed for simple cutting, filtering and
encoding tasks. It supports many file types, including AVI, DVD compatible
MPEG files, MP4 and ASF, using a variety of codecs.
Tasks can be automated using projects, job queue and powerful scripting
capabilities.

%package gtk
Summary:        GTK Graphical Frontend for %{name}
Group:          Productivity/Multimedia/Video/Editors and Convertors
Requires:       %{name} = %{version}-%{release}

%description gtk
Avidemux is a free video editor designed for simple cutting, filtering and
encoding tasks.
It supports many file types, including AVI, DVD compatible MPEG files, MP4 and
ASF, using a variety of codecs.
Tasks can be automated using projects, job queue and powerful scripting
capabilities.

This package contains the GTK based graphical frontend.

%package qt
Summary:        Qt4 Graphical Frontend for %{name}
Group:          Productivity/Multimedia/Video/Editors and Convertors
Requires:       %{name} = %{version}-%{release}

%description qt
Avidemux is a free video editor designed for simple cutting, filtering and
encoding tasks.
It supports many file types, including AVI, DVD compatible MPEG files, MP4 and
ASF, using a variety of codecs.
Tasks can be automated using projects, job queue and powerful scripting
capabilities.

This package contains the Qt based graphical frontend.

%package plugin-arts
Summary:        Arts output plugin for %{name}
Group:          Productivity/Multimedia/Video/Editors and Convertors
Requires:       %{name} = %{version}-%{release}

%description plugin-arts
Avidemux is a free video editor designed for simple cutting, filtering and
encoding tasks.
It supports many file types, including AVI, DVD compatible MPEG files, MP4 and
ASF, using a variety of codecs.
Tasks can be automated using projects, job queue and powerful scripting
capabilities.

This package contains the arts output plugin.

%lang_package

%prep
%setup -q -n "%{name}_%{version}"
dos2unix -q cmake/admDetermineSystem.cmake
dos2unix -q plugins/ADM_audioDecoders/ADM_ad_mad/CMakeLists.txt
sed -i -e 's|set(FFMPEG_VERSION 0.9)|set(FFMPEG_VERSION %{ffmpeg_version})|g' cmake/admFFmpegBuild.cmake
rm -f avidemux/ADM_libraries/ffmpeg-0.9.tar.bz2
cp %{S:4} avidemux/ADM_libraries/
pushd cmake/patches
rm -f libavcodec_libavcodec.v.patch
cp %{S:5} .
popd
%patch0
%patch1 -p1
%patch2 -p1
%patch3 -p1

%build
%if 0%{?sles_version}
export CXXFLAGS="-D__STDC_CONSTANT_MACROS -fno-strict-aliasing"
%else
export CXXFLAGS="-fno-strict-aliasing"
%endif

# libdir is hardcoded
%__sed -i -e "s|Dir=\"lib\"|Dir=\"%{_lib}\"|g" \
        avidemux/main.cpp \
        avidemux/ADM_core/src/ADM_fileio.cpp

# build main program
%__mkdir_p build
cd build
cmake \
        -DCMAKE_BUILD_TYPE=RelWithDebInfo \
        -DCMAKE_INSTALL_PREFIX=%{_prefix} \
        ..
%__make

# symlinking all libraries to build the plugins
%__mkdir_p lib
pushd lib
find ../../build/avidemux -name '*.so*' | xargs ln -sft .
popd

# build the plugins
cd ../plugins
%__mkdir_p build
pushd build
cmake \
        -DCMAKE_BUILD_TYPE=RelWithDebInfo \
        -DCMAKE_INSTALL_PREFIX=%{_prefix} \
        -DAVIDEMUX_SOURCE_DIR=%{_builddir}/%{name}_%{version} \
        -DAVIDEMUX_CORECONFIG_DIR=%{_builddir}/%{name}_%{version}/build/config \
        -DAVIDEMUX_INSTALL_PREFIX=%{_builddir}/%{name}_%{version}/build \
        ..
%__make
popd

%install
pushd build
%makeinstall
popd
pushd plugins/build
%makeinstall
popd

%if %{_lib} != lib
mv %{buildroot}/%{_prefix}/lib %{buildroot}/%{_libdir}
%endif

%__install -D -m 644 %{SOURCE1} %{buildroot}/%{_datadir}/pixmaps/%{name}.png

%__install -D -m 644 %{SOURCE2} %{buildroot}/%{_datadir}/applications/%{name}-gtk.desktop
%suse_update_desktop_file -r %{name}-gtk AudioVideo AudioVideoEditing

%__install -D -m 644 %{SOURCE3} %{buildroot}/%{_datadir}/applications/%{name}-qt4.desktop
%suse_update_desktop_file -r %{name}-qt4 AudioVideo AudioVideoEditing
%__rm -rf "%{buildroot}%{_bindir}/i18n"

%find_lang %{name}

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%clean
%__rm -rf "%{buildroot}"

%files
%defattr(-,root,root)
%{_bindir}/avidemux2_cli
%{_datadir}/pixmaps/%{name}.png
%{_libdir}/libADM_UICli.so
%{_libdir}/libADM_render_cli.so
%{_libdir}/libADM5avcodec.so.53
%{_libdir}/libADM5avformat.so.53
%{_libdir}/libADM5avutil.so.51
%{_libdir}/libADM5postproc.so.51
%{_libdir}/libADM5swscale.so.2
%{_libdir}/libADM_core.so
%{_libdir}/libADM_coreAudio.so
%{_libdir}/libADM_coreImage.so
%{_libdir}/libADM_coreUI.so
%{_libdir}/libADM_smjs.so
%dir %{_datadir}/ADM_scripts
%{_datadir}/ADM_scripts/*
%dir %{_datadir}/ADM_addons
%dir %{_datadir}/ADM_addons/avsfilter/
%{_datadir}/ADM_addons/avsfilter/*
%dir %{_libdir}/ADM_plugins
%dir %{_libdir}/ADM_plugins/audioDecoder
%{_libdir}/ADM_plugins/audioDecoder/libADM_ad_Mad.so
%{_libdir}/ADM_plugins/audioDecoder/libADM_ad_a52.so
%{_libdir}/ADM_plugins/audioDecoder/libADM_ad_faad.so
%{_libdir}/ADM_plugins/audioDecoder/libADM_ad_opencore_amrnb.so
%{_libdir}/ADM_plugins/audioDecoder/libADM_ad_opencore_amrwb.so
%{_libdir}/ADM_plugins/audioDecoder/libADM_ad_vorbis.so
%dir %{_libdir}/ADM_plugins/audioDevices
%{_libdir}/ADM_plugins/audioDevices/libADM_av_alsa.so
%{_libdir}/ADM_plugins/audioDevices/libADM_av_esd.so
%{_libdir}/ADM_plugins/audioDevices/libADM_av_jack.so
%{_libdir}/ADM_plugins/audioDevices/libADM_av_oss.so
%{_libdir}/ADM_plugins/audioDevices/libADM_av_pulseAudioSimple.so
%{_libdir}/ADM_plugins/audioDevices/libADM_av_sdl.so
%dir %{_libdir}/ADM_plugins/audioEncoders
%{_libdir}/ADM_plugins/audioEncoders/libADM_ae_faac.so
%{_libdir}/ADM_plugins/audioEncoders/libADM_ae_lame.so
%{_libdir}/ADM_plugins/audioEncoders/libADM_ae_lav_ac3.so
%{_libdir}/ADM_plugins/audioEncoders/libADM_ae_lav_mp2.so
%{_libdir}/ADM_plugins/audioEncoders/libADM_ae_pcm.so
%{_libdir}/ADM_plugins/audioEncoders/libADM_ae_twolame.so
%{_libdir}/ADM_plugins/audioEncoders/libADM_ae_vorbis.so
%dir %{_libdir}/ADM_plugins/videoEncoder
%dir %{_libdir}/ADM_plugins/videoEncoder/avcodec
%{_libdir}/ADM_plugins/videoEncoder/avcodec/Flv1Param.xsd
%{_libdir}/ADM_plugins/videoEncoder/avcodec/H263Param.xsd
%{_libdir}/ADM_plugins/videoEncoder/avcodec/MjpegParam.xsd
%{_libdir}/ADM_plugins/videoEncoder/avcodec/Mpeg2Param.xsd
%{_libdir}/ADM_plugins/videoEncoder/avcodec/Mpeg4aspParam.xsd
%dir %{_libdir}/ADM_plugins/videoEncoder/avcodec/mpeg-1
"%{_libdir}/ADM_plugins/videoEncoder/avcodec/mpeg-1/Video CD.xml"
%dir %{_libdir}/ADM_plugins/videoEncoder/avcodec/mpeg-2
%{_libdir}/ADM_plugins/videoEncoder/avcodec/mpeg-2/DVD.xml
"%{_libdir}/ADM_plugins/videoEncoder/avcodec/mpeg-2/Super Video CD.xml"
%{_libdir}/ADM_plugins/videoEncoder/avcodec/Mpeg1Param.xsd
%dir %{_libdir}/ADM_plugins/videoEncoder/mpeg2enc
%{_libdir}/ADM_plugins/videoEncoder/mpeg2enc/Mpeg1Param.xsd
%{_libdir}/ADM_plugins/videoEncoder/mpeg2enc/Mpeg2Param.xsd
%dir %{_libdir}/ADM_plugins/videoEncoder/mpeg2enc/mpeg-1
"%{_libdir}/ADM_plugins/videoEncoder/mpeg2enc/mpeg-1/Video CD.xml"
%dir %{_libdir}/ADM_plugins/videoEncoder/mpeg2enc/mpeg-2
%{_libdir}/ADM_plugins/videoEncoder/mpeg2enc/mpeg-2/DVD.xml
"%{_libdir}/ADM_plugins/videoEncoder/mpeg2enc/mpeg-2/Super Video CD.xml"
%{_libdir}/ADM_plugins/videoEncoder/libADM_vidEnc_avcodec.so
%{_libdir}/ADM_plugins/videoEncoder/libADM_vidEnc_x264.so
%{_libdir}/ADM_plugins/videoEncoder/libADM_vidEnc_xvid.so
%{_libdir}/ADM_plugins/videoEncoder/libADM_vidEnc_mpeg2enc.so
%dir %{_libdir}/ADM_plugins/videoEncoder/x264
"%{_libdir}/ADM_plugins/videoEncoder/x264/Apple iPhone.xml"
"%{_libdir}/ADM_plugins/videoEncoder/x264/Apple iPod 5.5G.xml"
"%{_libdir}/ADM_plugins/videoEncoder/x264/Apple iPod.xml"
"%{_libdir}/ADM_plugins/videoEncoder/x264/Microsoft Zune.xml"
"%{_libdir}/ADM_plugins/videoEncoder/x264/Sony PlayStation Portable.xml"
%{_libdir}/ADM_plugins/videoEncoder/x264/x264Param.xsd
%dir %{_libdir}/ADM_plugins/videoEncoder/xvid
%{_libdir}/ADM_plugins/videoEncoder/xvid/XvidParam.xsd
%dir %{_libdir}/ADM_plugins/videoFilter
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_Deinterlace.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_Delta.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_Denoise.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_FluxSmooth.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_Hue_cli.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_Mosaic.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_Pulldown.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_Stabilize.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_Tisophote.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_Whirl.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_addborders.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_asharp_cli.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_avisynthResize_cli.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_avsfilter.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_blackenBorders.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_blendDgBob.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_blendRemoval.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_chromashift_cli.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_cnr2_cli.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_colorYUV_cli.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_contrast_cli.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_crop_cli.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_decimate.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_denoise3d.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_denoise3dhq.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_dropOut.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_eq2_cli.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_equalizer_cli.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_fade.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_fastconvolutiongauss.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_fastconvolutionmean.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_fastconvolutionmedian.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_fastconvolutionsharpen.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_forcedPP.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_hzStackField.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_keepEvenField.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_keepOddField.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_kernelDeint.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_largemedian.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_lavDeinterlace.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_logo.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_lumaonly.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_mSharpen.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_mSmooth.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_mcdeint.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_mergeField.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_mpdelogo_cli.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_mplayerResize_cli.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_palShift.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_resampleFps.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_reverse.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_rotate.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_separateField.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_smartPalShift.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_smartSwapField.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_soften.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_ssa.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_stackField.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_sub_cli.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_swapField.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_swapuv.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_tdeint.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_telecide.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_unstackField.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_vflip.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_vlad.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_yadif.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vidChromaU.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vidChromaV.so

%files gtk
%defattr(-,root,root)
%{_bindir}/avidemux2_gtk
%{_datadir}/applications/%{name}-gtk.desktop
%{_libdir}/libADM_UIGtk.so
%{_libdir}/libADM_render_gtk.so
%{_libdir}/ADM_plugins/videoEncoder/x264/libADM_vidEnc_x264_Gtk.so
%{_libdir}/ADM_plugins/videoEncoder/xvid/libADM_vidEnc_Xvid_Gtk.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_Crop_gtk.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_asharp_gtk.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_avisynthResize_gtk.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_colorYUV_gtk.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_chromaShift_gtk.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_cnr2_gtk.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_contrast_gtk.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_eq2_gtk.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_equalizer_gtk.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_hue_gtk.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_mpdelogo_gtk.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_mplayerResize_gtk.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_sub_gtk.so

%files qt
%defattr(-,root,root)
%{_bindir}/avidemux2_qt4
%{_datadir}/applications/%{name}-qt4.desktop
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/i18n
%{_datadir}/%{name}/i18n/*.qm
%{_libdir}/libADM_UIQT4.so
%{_libdir}/libADM_render_qt4.so
%{_libdir}/ADM_plugins/videoEncoder/x264/libADM_vidEnc_x264_Qt.so
%{_libdir}/ADM_plugins/videoEncoder/xvid/libADM_vidEnc_Xvid_Qt.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_asharp_qt4.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_avisynthResize_qt4.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_chromaShift_qt4.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_cnr2_qt4.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_colorYUV_qt4.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_contrast_qt4.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_crop_qt4.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_curveEditor_qt4.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_eq2_qt4.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_equalizer_qt4.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_hue_qt4.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_mpdelogo_qt4.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_mplayerResize_qt4.so
%{_libdir}/ADM_plugins/videoFilter/libADM_vf_sub_qt4.so

%files plugin-arts
%defattr(-,root,root)
%{_libdir}/ADM_plugins/audioDevices/libADM_av_arts.so

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Wed Dec  9 2015 jslaby@suse.cz
- add fix-internal-plugins-load.patch
- build as RelWithDebInfo -- generate debuginfo
* Sat Dec 13 2014 joerg.lorenzen@ki.tng.de
- removed some unneeded dependencies to enable build on armv6l/armv6hl
* Sat Nov  8 2014 joerg.lorenzen@ki.tng.de
- added patch and dependencies to enable build on ARM CPU
* Fri Oct 17 2014 joerg.lorenzen@ki.tng.de
- enable build for SLES
* Tue Mar 25 2014 joerg.lorenzen@ki.tng.de
- update internal ffmpeg to version 0.9.4
* Sun Mar 16 2014 joerg.lorenzen@ki.tng.de
- build against libvpx
* Sat Feb  1 2014 joerg.lorenzen@ki.tng.de
- update internal ffmpeg to version 0.9.3
* Mon Jan  2 2012 detlef@links2linux.de
- new upstream version <2.5.6>
* Fri Sep  9 2011 Manfred.Tremmel@iiv.de
- included a patch to build against x264 >= 115
* Tue Jun  7 2011 detlef@links2linux.de
- new upstream version <2.5.5>
* Sat Nov 20 2010 detlef@links2linux.de
- add audioDevice.patch
  - add gtk_menu_dont_crash
  - add spelling_mistakes
* Mon Oct 25 2010 detlef@links2linux.de
- new upstream version <2.5.4>
* Sat Jul 24 2010 detlef@links2linux.de
- split arts output plugin
* Fri May 21 2010 detlef@links2linux.de
- new upstream version <2.5.3>
  * Fixed again partial filter
  * Added support for I420 video decoding
  * H.263 video encoder now supports more profiles
  * mpeg2enc video encoder no longer drops first few frames and now works on Win32
  * The majority of video encoders are now plugins
  * Updated the FFmpeg libraries
  * Updated libass
  * Avsproxy now supports audio
  * All auto wizards are now scripted and available in both interfaces
  * Needed files to compile your own plugins on windows (the *sdk*.zip file)
  * Various minor fixes and enhancements
* Sat Jan 30 2010 detlef@links2linux.de
- rebuild with new libx264
* Fri Jan  8 2010 detlef@links2linux.de
- rebuild with aften support
* Thu Dec 24 2009 detlef@links2linux.de
- rebuild with amrnb/amrwb support
- rebuild with newer x264 (80)
* Mon Dec 21 2009 detlef@links2linux.de
- new upstream version <2.5.2>
* Sat Nov  7 2009 pascal.bleser@opensuse.org
- fix VF_PARTIAL_FILTER: http://avidemux.org/admForum/viewtopic.php?id=6881
  thanks to Markus Kohm for reporting and testing
- use bzipped upstream source
* Wed Jul 22 2009 detlef@links2linux.de
- new upstream version <2.5.0>
  * Audio Codecs, Audio Devices and Video Filters are now plugins
  * x264 and Xvid encoders are now also plugins with an updated Qt interface
  * Auto wizards are now scripted and easier to extend
  * Updated the FFmpeg libraries
  * Various minor fixes and enhancements
* Thu Jan  8 2009 detlef@links2linux.de
- new upstream version <2.4.4>
  * Fixed crash when opening some MOV files (regression introduced in 2.4.3)
  * Improved support for H.264 in MPEG-TS and M2TS containers.
  * Improved support for H.264 in MP4 container (including constant frame rate fix)
  * Fixed bug where muxers could drop the first few B-frames (most containers were affected)
  * Fixed FAAC support so bitrate is correctly honoured
  * The same settings are now used for the first and second pass of an x264 encode
  * Improved JPEG file support
  * Improved PNG decoding (now uses libavcodec rather than a custom wrapper around libpng)
  * Improved BMP/DIB decoding (now uses libavcodec rather than using own decoder)
  * Improved colourspace handling for raw video, bitmaps and DIBs
  * Fixed Previous Black Frame functionality
  * Qt interface has been significantly upgraded and now fully functional (compared with its GTK counterpart)
  * Saving of video is now prevented if the A marker is greater than the B marker
  * Improvements made to ECMAscript including a new GetFilePath() function for the DirectorySearch class and fixes to the exec() function
  * Add support for AAC audio to the command line interface
  * Qt interface is now the default interface for MS Windows
  * x264 and Xvid stat files with Unicode characters are now handled on MS Windows
  * The application log file is no longer buffered on MS Windows to ensure sequential logging
  * Added support for ppc64 to the CMake build scripts
  * Updated the following translations: Catalan, Czech, French, Italian, Russian, Spanish
* Sun Jan  4 2009 detlef@links2linux.de
- build svn = 04.02.2009
* Thu Jul 24 2008 guru@unixtech.be
- new upstream version:
  * better support for x264 and .mp4 files bigger than 4GB
* Tue Jul 15 2008 guru@unixtech.be
- split into -gtk and -qt subpackages
- enabled pulseaudio support (new in 2.4.2)
- added a check for enabled features by grepping the cmake log
- fixed aften support by requiring libaften-devel instead of aften
- fixed MP3 support by requiring libmp3lame-devel instead of lame
* Mon Jul 14 2008 detlef@links2linux.de
- new upstream version <2.4.2>:
  * improved input and output of audio streams in MKV files
  * support for MJPEG-A in MOV/MP4 files
  * fixed saving header information of AVI files with PCM/LPCM audio
  * fixed opening FLV files that don't contain audio
  * fixed corruption when decoding MP4 files
  * fixed crashing when using MPEG-4 ASP (lavc) and two pass average bitrate mode
  * flush the x264 encoder upon completion so the last few frames aren't dropped
  * fixed incorrect colour conversion of 24/32 bit BMP and DIB files
  * re-enabled AMR-NB decoder (regression introduced in 2.4.0)
  * Xvid custom matrices are now activated correctly
  * fixed caching issue with Qt4 interface which would corrupt translated strings
  * fixed zooming when using SDL (regression introduced in 2.4.1)
  * windows are now centred correctly on multi-monitor setups
  * use alternate button ordering for GTK+ interface when GNOME HIG isn't appropriate, e.g. MS Windows and KDE
  * various additions to the Qt4 interface including a new calculator tool, drag and drop support, improved joblist support and an about window
  * SRT subtitle support for Arabic, Baltic, Greek, Hebrew and Turkish
  * fixed iPod profile where audio encoding options weren't always set correctly
  * fixed Film to PAL audio filter so frames are removed and added correctly
  * batch importing of image files is no longer restricted by the file handle limit set by the C runtime
  * new video filter for outputting the frame number
  * PulseAudio support (Linux only)
  * updated the following translations: Czech, French, German, Greek, Italian, Spanish
  * various minor fixes and enhancements
* Thu Jul 10 2008 guru@unixtech.be
- changed BuildRequires:faac to libfaac-devel to fix faac support
* Mon Feb 18 2008 detlef@links2linux.de
- new upstream version <2.4.1>
* Sat Dec 29 2007 detlef@links2linux.de
- rebuild with new libx264
* Fri Dec 28 2007 detlef@links2linux.de
- disable qt4 for 10.2
* Mon Dec 24 2007 detlef@links2linux.de
- new upstream version <2.4>
- merge avidemux-svn and avidemux24 to avidemux
* Fri Dec 21 2007 detlef@links2linux.de
- new svn snapshot
* Mon Nov 12 2007 detlef@links2linux.de
- fix file permissions
* Sun Oct 28 2007 detlef@links2linux.de
- fix typo debug_package
* Sat Oct 27 2007 detlef@links2linux.de
- build svn shots <20071027>
* Thu Aug  2 2007 detlef@links2linux.de
- new preview-release
* Sun Mar 18 2007 detlef@links2linux.de
- new preview-release
* Mon Nov  6 2006 detlef@links2linux.de
- rebuild for new x624
* Fri Oct 27 2006 detlef@links2linux.de
- update to 2.3_preview2b
* Sun Jul  2 2006 detlef@links2linux.de
- update to 2.2_preview2b
* Sun Mar  5 2006 detlef@links2linux.de
- update to 2.1.2
* Thu Jul 29 2004 rainer@links2linux.de
- configure with --with-debug
* Mon Sep 29 2003 rainer@links2linux.de
- added jpeg patch
* Mon Aug  4 2003 Rainer@links2linux.de
- first packman release
* Mon Jun 30 2003 rainer@links2linux.de
- changed to version 2
* Mon Nov 11 2002 rainer.lay@cs.fau.de
- first SuSE 8.0 release
* Tue Nov  5 2002 florin@andrei.myip.org
- v0.9pre18-1
- moved over to Red Hat 8.0
* Thu Aug 22 2002 florin@andrei.myip.org
- first version (0.9pre12-1)
